@@ -68,7 +68,7 @@ class Message(six.text_type):
         msg.has_plural_form = has_plural_form
         return msg
 
-    def translate(self, desired_locale=None):
+    def translation(self, desired_locale=None):
         """Translate this message to the desired locale.
 
         :param desired_locale: The desired locale to translate the message to,
@@ -77,7 +77,6 @@ class Message(six.text_type):
 
         :returns: the translated message in unicode
         """
-
         translated_message = Message._translate_msgid(self.msgid,
                                                       self.domain,
                                                       desired_locale,
